@@ -1,35 +1,3 @@
-
-=head1 NAME
-
-WebService::Amazon::Route53::Caching::Store::DBM - DBM-based cache-storage.
-
-=head1 SYNOPSIS
-
-This module implements several methods which makes it possible to
-get/set/delete cached values by a string-key.
-
-The module will expect to be passed a filename to use for the cache in
-the constructor:
-
-=for example begin
-
-    my $redis = Redis->new();
-    my $cache = WebService::Amazon::Route53::Caching::Store::DBM->new( path => "/tmp/db.db" );
-
-=for example end
-
-=cut
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2014 Steve Kemp <steve@steve.org.uk>.
-
-This library is free software. You can modify and or distribute it under
-the same terms as Perl itself.
-
-=cut
-
-
 use strict;
 use warnings;
 
@@ -140,7 +108,6 @@ sub del
     tie %h, "DB_File", $self->{ '_path' }, O_RDWR | O_CREAT, 0666, $DB_HASH or
       return;
 
-    $h{$key} = "[deleted]";
     delete $h{ $key };
     untie(%h);
 }
